<template>
  <el-dialog
    :title="title"
    :visible="dialogVisible"
    width="1200px"
    append-to-body
  >
    <div class="flex_box">
      <div class="left" :style="{ width: leftWidth }">
        <div class="isExpand_box">
          <el-link type="primary" @click="hideTree">
            <i
              :class="isExpand ? 'el-icon-arrow-left' : 'el-icon-arrow-right'"
            ></i>
            {{ isExpand ? "收缩" : "展开" }}
          </el-link>
        </div>
        <el-input
          placeholder="输入关键字进行过滤"
          v-model="filterText"
          size="small"
          v-show="isExpand"
        >
        </el-input>
        <el-tree
          v-show="isExpand"
          class="filter_tree"
          :data="data"
          default-expand-all
          :filter-node-method="filterNode"
          ref="tree"
        >
        </el-tree>
      </div>
      <div class="right">
        <div class="tab_box">
          <el-tabs v-model="activeName" type="card" @tab-click="handleClick">
            <el-tab-pane label="正确数据" name="success">
              <el-table border :data="successData"></el-table>
            </el-tab-pane>
            <el-tab-pane label="有相似项或者错误数据" name="error">
              <el-table border :data="errorData"></el-table>
            </el-tab-pane>
          </el-tabs>
        </div>
      </div>
    </div>
    <template #footer>
      <div>
        <el-button size="small" type="primary">确定导入</el-button>
        <el-button size="small">取消</el-button>
      </div>
    </template>
  </el-dialog>
</template>

<script>
export default {
  name: "ShowImportData",
  props: {
    title: {
      type: String,
      default: "历史数据导入",
    },
    visible: false,
  },
  computed: {
    dialogVisible: {
      get() {
        return this.visible;
      },
      set(val) {
        this.$emit("update:visible", val);
      },
    },
  },
  data() {
    return {
      isExpand: true,
      filterText: "",
      leftWidth: "200px",
      data: [
        {
          id: 1,
          label: "一级 1",
          children: [
            {
              id: 4,
              label: "二级 1-1",
              children: [
                {
                  id: 9,
                  label: "三级 1-1-1",
                },
                {
                  id: 10,
                  label: "三级 1-1-2",
                },
              ],
            },
          ],
        },
        {
          id: 2,
          label: "一级 2",
          children: [
            {
              id: 5,
              label: "二级 2-1",
            },
            {
              id: 6,
              label: "二级 2-2",
            },
          ],
        },
        {
          id: 3,
          label: "一级 3",
          children: [
            {
              id: 7,
              label: "二级 3-1",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
          ],
        },
      ],
      successData: [],
      errorData: [],
    };
  },

  methods: {
    filterNode(value, data) {
      if (!value) return true;
      return data.label.indexOf(value) !== -1;
    },
    hideTree() {
      if (this.isExpand) {
        this.leftWidth = "50px";
      } else {
        this.leftWidth = "200px";
      }
      this.isExpand = !this.isExpand;
    },
  },
  watch: {
    filterText(val) {
      this.$refs.tree.filter(val);
    },
  },
};
</script>

<style lang="scss" scoped>
.flex_box {
  display: flex;
  .left {
    transition: all 0.3s;
    .isExpand_box {
      margin-bottom: 10px;
      text-align: right;
    }
    .filter_tree {
      max-height: 400px;
      overflow-y: scroll;
    }
  }
}
</style>
